Credits
=======

``Avenue`` is written and maintained by `Nils Corver <http://corverdevelopment.nl/>`_.

A full list of contributors can be found in
`GitHub's overview <https://github.com/corverdevelopment/avenue/graphs/contributors>`_.
